@@ -1,5 +1,6 @@
 import re
 import datetime
+from typing import Union
 from pathlib import Path
 from enum import Enum
 
@@ -8,8 +9,9 @@ Polarization = Enum("Polarization", "VV VH")
 
 
 class FileName:
-    def __init__(self, path):
+    def __init__(self, path: Union[Path, str]) -> None:
         self.path = Path(path)
+
         pattern = (
                 r"^s1[ab]-"
                 r"(?P<mode>(iw|ew|wv|im))-"
@@ -30,22 +32,21 @@ class FileName:
         self.props = match.groupdict()
 
     @property
-    def mode(self):
+    def mode(self) -> str:
         return self.props["mode"]
 
     @property
-    def product(self):
+    def product(self) -> str:
         return self.props["product"]
 
     @property
-    def polarization(self):
+    def polarization(self) -> str:
         return self.props["polarization"]
 
     @property
-    def start(self):
+    def start(self) -> datetime.datetime:
         return datetime.datetime.strptime(self.props["start"], "%Y%m%dT%H%M%S")
 
     @property
-    def stop(self):
+    def stop(self) -> datetime.datetime:
         return datetime.datetime.strptime(self.props["stop"], "%Y%m%dT%H%M%S")
-
