@@ -1,5 +1,6 @@
 import re
 import datetime
+from typing import Union
 from pathlib import Path
 from enum import Enum
 
@@ -8,7 +9,7 @@ Polarization = Enum("Polarization", "VV VH")
 
 
 class Tile:
-    def __init__(self, path):
+    def __init__(self, path: Union[Path, str]) -> None:
         self.path = Path(path)
 
         pattern = (
@@ -34,22 +35,25 @@ class Tile:
         self.props = match.groupdict()
 
     @property
-    def mode(self):
+    def mode(self) -> str:
         return self.props["mode"]
 
     @property
-    def product(self):
+    def product(self) -> str:
         return self.props["product"]
 
     @property
-    def polarization(self):
+    def polarization(self) -> str:
         return self.props["polarization"]
 
     @property
-    def start(self):
+    def start(self) -> datetime.datetime:
         return datetime.datetime.strptime(self.props["start"], "%Y%m%dT%H%M%S")
 
     @property
-    def stop(self):
+    def stop(self) -> datetime.datetime:
         return datetime.datetime.strptime(self.props["stop"], "%Y%m%dT%H%M%S")
 
+    def get_band(self, polarization: Polarization) -> Path:
+        tif = next(self.path.glob(f"measurement/*-{polarization.name.lower()}-*.tiff"))
+        return tif
