@@ -5,7 +5,7 @@ import sentile.scripts.s1
 import sentile.scripts.s2
 
 
-def main():
+def main() -> None:
     parser = argparse.ArgumentParser(prog="sentile")
 
     subcmd = parser.add_subparsers(dest="command")
