@@ -1,7 +1,7 @@
 from sentile.s1 import Tile, Polarization
 
 
-def main(args):
+def main(args) -> None:
     tile = Tile(args.tile)
 
     print("product", tile.product)
