@@ -1,7 +1,7 @@
 from sentile.s2 import Tile
 
 
-def main(args):
+def main(args) -> None:
     tile = Tile(args.tile)
 
     print("name", tile.name)
